function L=int2logical(M,b)
%Retreive a maximum of 8 logicals from a uint8 variable
%
% CALL
%     L=int2logical(M)
%     L=int2logical(M, b)
%
% INPUT
%     M(I1,I2,...): uint8 matrix
%     b: bits to read (default : all)
%        %examples b=1, b=[1 3], default: b=1:8
%
% OUTPUT
%     M(8,I1,I2,...): logical matrix: contains corresponding logicals
%                     Note: if V= is a horizontal vector of length(N):
%                              size(int2logical(V))=[8 x 1 x N]
%                     if V= is a vertical vector of length(N):
%                              size(int2logical(V))=[8 x N]
%
% SEE ALSO
%     logical2int,bitget
%
% if nargin==0 %testmode
%     L=int2logical(uint8([2 3; 4 5]))
%     M=logical2int(L)
%     return
% end
% 
% NOTE:
%     To retrieve 1 bit, one might as well use bitget(M,bitnr)

%REVISION JULI 2006
%     also allow uint16, uint32
switch class(M)
    case 'uint8'
        NDIM=8;
    case 'uint16'
        NDIM=16;
    case 'uint32'
        NDIM=32;
    otherwise
        error('function only applies to uint8, uint16 or uint32');
end
if isempty(M)
    %return empty matrix of logical
    L=false([0 0]);
    return
end
if nargin<2
    %default: return all bits
    b=1:NDIM;
else
    %retrieve specific bits
    if any(b<1|b>NDIM)
        error('Attempt to read invalid bit');
    end
end
%add length(b) dimensions
if length(b)>1
    %WIJZ ZIJPP APR 2006: NO NEED to rehape vectors
    %     if isvector(M) && size(M,1)>1 %Vertical vector
    %         %do not attempt to return 8xMx1 matrix, but construct 8xM matrix
    %         %directlty
    %         M=reshape(M,1,prod(size(M)));
    %     end
    newsize=[length(b),size(M)];
    L=false(newsize);
    for k=1:length(b)
        submat=logical(bitget(M,b(k)));
        L(k,:)=submat(:);
    end
else
    %simple method: return matrix of size M
    L=logical(bitget(M,b));
end
